@@ -50,7 +50,7 @@ class ListTemplatesRequest(RpcRequest):
 		self.add_query_param('TemplateName',TemplateName)
 
 	def get_Tags(self):
-		return self.get_query_params().get('Tags')
+		return self.get_query_params().get('Tag')
 
 	def set_Tags(self, Tags):
 		for depth1 in range(len(Tags)):
