@@ -80,7 +80,7 @@ class PreviewStackRequest(RpcRequest):
 		self.add_query_param('StackPolicyURL',StackPolicyURL)
 
 	def get_Parameterss(self):
-		return self.get_query_params().get('Parameterss')
+		return self.get_query_params().get('Parameters')
 
 	def set_Parameterss(self, Parameterss):
 		for depth1 in range(len(Parameterss)):
