@@ -44,7 +44,7 @@ class UpdateStackGroupRequest(RpcRequest):
 		self.add_query_param('RegionIds',RegionIds)
 
 	def get_Parameterss(self):
-		return self.get_query_params().get('Parameterss')
+		return self.get_query_params().get('Parameters')
 
 	def set_Parameterss(self, Parameterss):
 		for depth1 in range(len(Parameterss)):
