@@ -50,7 +50,7 @@ class UpdateStackRequest(RpcRequest):
 		self.add_query_param('DisableRollback',DisableRollback)
 
 	def get_Parameterss(self):
-		return self.get_query_params().get('Parameterss')
+		return self.get_query_params().get('Parameters')
 
 	def set_Parameterss(self, Parameterss):
 		for depth1 in range(len(Parameterss)):
